==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/my_library.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($library['library_id'])) {
						?>
						<a href="my_library_edit.php?library_id=<?php echo $library['library_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_this'];?></a><br />
						<?php
						}
						elseif (!isset($_REQUEST['history_library_id'])) {
						?>
						<a href="my_library_edit.php?library_id=0" class="txt_sub_menu"><?php echo $lang['href_add'];?></a><br />
						<?php
						}
						?>

						<a href="my_library.php" class="txt_sub_menu"><?php echo $lang['href_default'];?></a><br />
						<a href="my_library.php?contents=1" class="txt_sub_menu"><?php echo $lang['href_contents'];?></a><br />

					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>

		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">

			<?php
			if (isset($display) && $display == "history") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_history'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($history[0])) {
				foreach($history as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="my_library.php?user_id=<?php echo $user['user_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['display_library_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_history'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>


			<?php
			}
			elseif (isset($display) && $display == "contents") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="5" class="txt_title" align="right">
						<?php echo $lang['hdr_contents'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($contents[0])) {
				foreach($contents as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="my_library.php?user_id=<?php echo $user['user_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['display_library_create_datetime'];?><br />
					</td>
					<td valign="top">
						<?php
						if (isset($i['library_publish'])) {
						    echo $lang['arr_item_publish'][$i['library_publish']];
						}
						?><br />
					</td>
					<td valign="top">
						<?php
						if ($i['library_default'] == 1) {
						    echo $lang['txt_default'];
						}
						?><br />
					</td>
					<td valign="top">
						<?php echo $i['library_total_views'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer" colspan="5">
						<?php echo $i['library_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="5">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_contents'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			}
			else {
			?>

			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<?php
				if (isset($library['library_id'])) {
				?>

				<tr>
					<td class="txt_title" align="right">
						<?php echo $library['library_title'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
				<?php }?>

			</table>

			<?php
			}
			?>
		</td>
	</tr>
</table>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/my_library.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($library_first_page)) {
						?>
						<a href="my_library_edit.php?user_id=<?php echo $user['user_id'];?>&amp;page=<?php echo $library_first_page;?>" class="txt_sub_menu"><?php echo $lang['href_wiki_first_page'];?></a><br />
						<?php 
						}
						else {
						?>
						<a href="my_library_edit.php?library_id=<?php echo $library['library_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_this'];?></a><br />
						<a href="my_library.php" class="txt_sub_menu"><?php echo $lang['href_default'];?></a><br />
						<a href="my_library.php?contents=1" class="txt_sub_menu"><?php echo $lang['href_contents'];?></a><br />
						<?php
						}
						?>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>

		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">

			<?php
			if (isset($display) && $display == "history") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_history'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($history)) {
				foreach($history as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="my_library.php?user_id=<?php echo $user['user_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['display_library_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_history'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>


			<?php
			}
			elseif (isset($display) && $display == "contents") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="5" class="txt_title" align="right">
						<?php echo $lang['hdr_contents'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($contents)) {
				foreach($contents as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="my_library.php?user_id=<?php echo $user['user_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['display_library_create_datetime'];?><br />
					</td>
					<td valign="top">
						<?php
						if (isset($i['library_publish'])) {
						    echo $lang['arr_item_publish'][$i['library_publish']];
						}
						?><br />
					</td>
					<td valign="top">
						<?php
						if ($i['library_default'] == 1) {
						    echo $lang['txt_default'];
						}
						?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer" colspan="5">
						<?php echo $i['library_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="5">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_contents'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			}
			else {
			?>

			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_library'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($library['library_id'])) {
				?>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $library['library_title'];?><br />
						</span>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" cellpadding="0" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_comments'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($comments)) {
				foreach($comments as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0">
							<tr>
								<td class="txt_footer" colspan="2">
									<?php echo $lang['txt_from'];?>: <a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>" class="txt_footer_link"><?php echo $i['profile_nic'];?></a>&nbsp;(<?php echo $lang['txt_joined'];?>: <?php echo $i['profile_create_datetime'];?>, <?php echo $lang['txt_hometown'];?>: <?php echo $i['profile_hometown'];?>)<br />
									<?php echo $lang['txt_comment_datetime'];?>: <?php echo $i['comment_create_datetime'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<?php echo $i['comment_body'];?><br />
								</td>
						    </tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_comments'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			<?php
			}
			?>
			
			
		</td>
	</tr>
</table>
